==> resiprocate_1.8.5.orig.tar.gz: resiprocate-1.8.5/tfm/CountDown.cxx <==
#include "tfm/CountDown.hxx"

CountDown::CountDown(unsigned int count, resip::Data description)
   : _description(description),
     _count(count)
{}

CountDown::CountDownDec::CountDownDec(CountDown* countdown) : _countdown(countdown) 
{}

CountDown::CountDownDec::~CountDownDec()
{}

void CountDown::CountDownDec::operator()(boost::shared_ptr<Event> event)
{
   _countdown->_count--;
}

CountDown::CountDownDec* 
CountDown::dec()
{
   return new CountDownDec(this); 
}

resip::Data CountDown::toString() const
{
   return _description + " " + resip::Data((unsigned long)_count);
}

bool CountDown::passes(boost::shared_ptr<Event>)
{
   return (_count == 0);
}
/*
  Copyright (c) 2005, PurpleComm, Inc. 
  All rights reserved.

  Redistribution and use in source and binary forms, with or without modification,
  are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, this
    list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  * Neither the name of PurpleComm, Inc. nor the names of its contributors may
    be used to endorse or promote products derived from this software without
    specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

==> resiprocate_1.9.7.orig.tar.gz: resiprocate-1.9.7/tfm/CountDown.cxx <==
#include "tfm/CountDown.hxx"

CountDown::CountDown(unsigned int count, resip::Data description)
   : _description(description),
     _count(count)
{}

CountDown::CountDownDec::CountDownDec(CountDown* countdown) : _countdown(countdown) 
{}

CountDown::CountDownDec::~CountDownDec()
{}

void CountDown::CountDownDec::operator()(boost::shared_ptr<Event> event)
{
   _countdown->_count--;
}

CountDown::CountDownDec* 
CountDown::dec()
{
   return new CountDownDec(this); 
}

resip::Data CountDown::toString() const
{
   return _description + " " + resip::Data(_count);
}

bool CountDown::passes(boost::shared_ptr<Event>)
{
   return (_count == 0);
}
/*
  Copyright (c) 2005, PurpleComm, Inc. 
  All rights reserved.

  Redistribution and use in source and binary forms, with or without modification,
  are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, this
    list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  * Neither the name of PurpleComm, Inc. nor the names of its contributors may
    be used to endorse or promote products derived from this software without
    specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
